@@ -26,7 +26,7 @@ This file is the "main" file of this package (implements the main function,
 the Server class and the Configuration class).
 """
 
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -402,8 +402,11 @@ class Server:
             headers["X-XSS-Protection"] = "1; mode=block"
             headers["X-Content-Type-Options"] = "nosniff"
             headers["Referrer-Policy"] = "origin-when-cross-origin"
-            headers["Cache-Control"] = "no-store"
-            headers["Pragma"] = "no-store"
+            headers[
+                "Cache-Control"
+            ] = "no-cache, no-store, must-revalidate, private"
+            headers["Pragma"] = "no-cache"
+            headers["Expires"] = "0"
             headers["Clear-Site-Data"] = '"cache", "executionContexts"'
             headers["Feature-Policy"] = (
                 "payment 'none'; geolocation 'none'; "
@@ -415,6 +418,10 @@ class Server:
             headers["Cross-Origin-Embedder-Policy"] = "require-corp"
             headers["Cross-Origin-Opener-Policy"] = "same-origin"
             headers["Cross-Origin-Resource-Policy"] = "same-origin"
+            headers["Sec-Fetch-Mode"] = "document"
+            headers["Sec-Fetch-Site"] = "same-site"
+            headers["Sec-Fetch-Mode"] = "navigate"
+            headers["Sec-Fetch-User"] = "?1"
             headers["X-Server"] = "WebScripts"
         else:
             logger_warning(
@@ -430,8 +437,14 @@ class Server:
                 configuration.exclude_auth_pages.append("/csp/debug/")
 
             headers["Content-Security-Policy-Report-Only"] = (
-                "default-src 'self'; form-action 'none'; "
-                "frame-ancestors 'none'; report-uri /csp/debug/"
+                "default-src 'self'; navigate-to 'self'; worker-src "
+                "'none'; style-src-elem 'self'; style-src-attr 'none';"
+                " style-src 'self'; script-src-attr 'none'; object-src"
+                " 'none'; media-src 'none'; manifest-src 'none'; "
+                "frame-ancestors 'none'; connect-src 'self'; font-src"
+                " 'none'; img-src 'self'; base-uri 'none'; child-src"
+                " 'none'; form-action 'none'; script-src 'self' "
+                "'require-trusted-types-for'; report-uri /csp/debug/"
             )
 
         logger_info("Default HTTP headers are set.")
@@ -791,7 +804,7 @@ class Server:
         """
 
         def check_argument_count():
-            if isinstance(object_, FunctionType) or type(object_) == type:
+            if isinstance(object_, FunctionType) or type(object_) is type:
                 if arg_count == 7:
                     logger_info(f"Function page found {object_}.")
                     return object_, is_not_package
