@@ -25,7 +25,7 @@ This tool runs CLI scripts and displays output in a Web Interface.
 This file implements commons functions and class for WebScripts package.
 """
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -779,16 +779,24 @@ class CallableFile(Callable):
 
     @log_trace
     def __init__(
-        self, type_: str, path_: str, filename: str, config: dict = None
+        self,
+        type_: str,
+        path_: str,
+        filename: str,
+        config: dict = None,
+        security: bool = True,
     ):
         self.path = path_
         self.type = type_
         self.config = config
+        self.security = security
         self.filename = filename
         self.extension = splitext(path_)[1].lower()
 
     @log_trace
-    def __call__(self, user: User) -> Tuple[str, Dict[str, str], List[bytes]]:
+    def __call__(
+        self, user: User, subdirectory: int = 2
+    ) -> Tuple[str, Dict[str, str], List[bytes]]:
         if self.type == "js":
             return (
                 "200 OK",
@@ -882,42 +890,51 @@ class CallableFile(Callable):
                 )
         elif self.type == "script":
             nonce = token_hex(20)
+            subpath = "../" * subdirectory
+            template = CallableFile.template_script.replace(
+                'src="../js/', 'src="' + subpath + "js/"
+            ).replace('href="../static/', 'href="' + subpath + "static/")
             return (
                 "200 OK",
                 {
                     "Content-Type": "text/html; charset=utf-8",
-                    "Content-Security-Policy": (
+                    (
+                        "Content-Security-Policy"
+                        if self.security
+                        else "Content-Security-Policy-Report-Only"
+                    ): (
                         "default-src 'self'; navigate-to 'self'; worker-src "
                         "'none'; style-src-elem 'self'; style-src-attr 'none';"
                         " style-src 'self'; script-src-attr 'none'; object-src"
                         " 'none'; media-src 'none'; manifest-src 'none'; "
-                        "frame-ancestors 'none'; connect-src 'self'; font-src"
+                        "connect-src 'self'; font-src"
                         " 'none'; img-src 'self'; base-uri 'none'; child-src"
                         " 'none'; form-action 'none'; script-src 'self' "
                         f"'nonce-{nonce}' 'require-trusted-types-for'"
                     ),
                 },
-                CallableFile.template_script
+                (
+                    template
+                    if self.security
+                    else template.replace(
+                        "Content-Security-Policy",
+                        "Content-Security-Policy-Report-Only",
+                    )
+                )
                 % {
                     "name": self.filename,
                     "user": user.name,
                     "csrf": TokenCSRF.build_token(user),
                     "nonce": nonce,
-                    "header": self.template_header,
-                    "footer": self.template_footer,
+                    "header": self.template_header.replace(
+                        'href="../web/', 'href="' + subpath + "web/"
+                    ),
+                    "footer": self.template_footer.replace(
+                        'href="../static/', 'href="' + subpath + "static/"
+                    ),
+                    "subpath": subpath,
                 },
             )
-            # return (
-            #     "200 OK",
-            #     {"Content-Type": "text/html"},
-            #     CallableFile.template_script
-            #     % {
-            #         "name": self.filename,
-            #         "user": user.name,
-            #         "csrf": TokenCSRF.build_token(user),
-            #         "nonce": nonce,
-            #     },
-            # )
 
     def is_xml(self) -> bool:
         """
