@@ -163,8 +163,14 @@ class TestServer(TestCase):
             self.server_unsecure.headers[
                 "Content-Security-Policy-Report-Only"
             ],
-            "default-src 'self'; form-action 'none'; frame-ancestors 'none'"
-            "; report-uri /csp/debug/",
+            "default-src 'self'; navigate-to 'self'; worker-src "
+            "'none'; style-src-elem 'self'; style-src-attr 'none';"
+            " style-src 'self'; script-src-attr 'none'; object-src"
+            " 'none'; media-src 'none'; manifest-src 'none'; "
+            "frame-ancestors 'none'; connect-src 'self'; font-src"
+            " 'none'; img-src 'self'; base-uri 'none'; child-src"
+            " 'none'; form-action 'none'; script-src 'self' "
+            "'require-trusted-types-for'; report-uri /csp/debug/",
         )
         self.assertListEqual(
             self.conf_unsecure.modules, ["csp", "Configurations"]
@@ -342,8 +348,11 @@ class TestServer(TestCase):
         headers["X-XSS-Protection"] = "1; mode=block"
         headers["X-Content-Type-Options"] = "nosniff"
         headers["Referrer-Policy"] = "origin-when-cross-origin"
-        headers["Cache-Control"] = "no-store"
-        headers["Pragma"] = "no-store"
+        headers[
+            "Cache-Control"
+        ] = "no-cache, no-store, must-revalidate, private"
+        headers["Pragma"] = "no-cache"
+        headers["Expires"] = "0"
         headers["Clear-Site-Data"] = '"cache", "executionContexts"'
         headers["Feature-Policy"] = (
             "payment 'none'; geolocation 'none'; "
@@ -355,6 +364,10 @@ class TestServer(TestCase):
         headers["Cross-Origin-Embedder-Policy"] = "require-corp"
         headers["Cross-Origin-Opener-Policy"] = "same-origin"
         headers["Cross-Origin-Resource-Policy"] = "same-origin"
+        headers["Sec-Fetch-Mode"] = "document"
+        headers["Sec-Fetch-Site"] = "same-site"
+        headers["Sec-Fetch-Mode"] = "navigate"
+        headers["Sec-Fetch-User"] = "?1"
         headers["X-Server"] = "WebScripts"
 
         self.assertDictEqual(h, headers)
@@ -368,8 +381,14 @@ class TestServer(TestCase):
             h,
             {
                 "Content-Security-Policy-Report-Only": (
-                    "default-src 'self'; form-action 'none'; "
-                    "frame-ancestors 'none'; report-uri /csp/debug/"
+                    "default-src 'self'; navigate-to 'self'; worker-src "
+                    "'none'; style-src-elem 'self'; style-src-attr 'none';"
+                    " style-src 'self'; script-src-attr 'none'; object-src"
+                    " 'none'; media-src 'none'; manifest-src 'none'; "
+                    "frame-ancestors 'none'; connect-src 'self'; font-src"
+                    " 'none'; img-src 'self'; base-uri 'none'; child-src"
+                    " 'none'; form-action 'none'; script-src 'self' "
+                    "'require-trusted-types-for'; report-uri /csp/debug/"
                 )
             },
         )
